package com.bonus.canteen.core.kitchen.mapper;

import java.util.List;
import com.bonus.canteen.core.kitchen.domain.KitchenWasteDeal;

/**
 * 厨房废弃物处置Mapper接口
 * 
 * @author xsheng
 * @date 2025-06-16
 */
public interface KitchenWasteDealMapper {
    /**
     * 查询厨房废弃物处置
     * 
     * @param wasteId 厨房废弃物处置主键
     * @return 厨房废弃物处置
     */
    public KitchenWasteDeal selectKitchenWasteDealByWasteId(Long wasteId);

    /**
     * 查询厨房废弃物处置列表
     * 
     * @param kitchenWasteDeal 厨房废弃物处置
     * @return 厨房废弃物处置集合
     */
    public List<KitchenWasteDeal> selectKitchenWasteDealList(KitchenWasteDeal kitchenWasteDeal);

    /**
     * 新增厨房废弃物处置
     * 
     * @param kitchenWasteDeal 厨房废弃物处置
     * @return 结果
     */
    public int insertKitchenWasteDeal(KitchenWasteDeal kitchenWasteDeal);

    /**
     * 修改厨房废弃物处置
     * 
     * @param kitchenWasteDeal 厨房废弃物处置
     * @return 结果
     */
    public int updateKitchenWasteDeal(KitchenWasteDeal kitchenWasteDeal);

    /**
     * 删除厨房废弃物处置
     * 
     * @param wasteId 厨房废弃物处置主键
     * @return 结果
     */
    public int deleteKitchenWasteDealByWasteId(Long wasteId);

    /**
     * 批量删除厨房废弃物处置
     * 
     * @param wasteIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteKitchenWasteDealByWasteIds(Long[] wasteIds);
}
