package com.bonus.canteen.core.kitchen.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.kitchen.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.kitchen.domain.KitchenWasteDeal;
import com.bonus.canteen.core.kitchen.service.IKitchenWasteDealService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 厨房废弃物处置Controller
 * 
 * @author xsheng
 * @date 2025-06-16
 */
@Api(tags = "厨房废弃物处置接口")
@RestController
@RequestMapping("/kitchen_waste_deal")
public class KitchenWasteDealController extends BaseController {
    @Autowired
    private IKitchenWasteDealService kitchenWasteDealService;

    /**
     * 查询厨房废弃物处置列表
     */
    @ApiOperation(value = "查询厨房废弃物处置列表")
    //@RequiresPermissions("kitchen:deal:list")
    @PostMapping("/list")
    public TableDataInfo list(@RequestBody @Valid KitchenWasteDeal kitchenWasteDeal) {
        startPage();
        List<KitchenWasteDeal> list = kitchenWasteDealService.selectKitchenWasteDealList(kitchenWasteDeal);
        return getDataTable(list);
    }

    /**
     * 导出厨房废弃物处置列表
     */
    @ApiOperation(value = "导出厨房废弃物处置列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:deal:export")
    @SysLog(title = "厨房废弃物处置", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出厨房废弃物处置")
    @PostMapping("/export")
    public void export(HttpServletResponse response, KitchenWasteDeal kitchenWasteDeal) {
        List<KitchenWasteDeal> list = kitchenWasteDealService.selectKitchenWasteDealList(kitchenWasteDeal);
        ExcelUtil<KitchenWasteDeal> util = new ExcelUtil<KitchenWasteDeal>(KitchenWasteDeal.class);
        util.exportExcel(response, list, "厨房废弃物处置数据");
    }

    /**
     * 获取厨房废弃物处置详细信息
     */
    @ApiOperation(value = "获取厨房废弃物处置详细信息")
    //@RequiresPermissions("kitchen:deal:query")
    @GetMapping(value = "/{wasteId}")
    public AjaxResult getInfo(@PathVariable("wasteId") Long wasteId) {
        return success(kitchenWasteDealService.selectKitchenWasteDealByWasteId(wasteId));
    }

    /**
     * 新增厨房废弃物处置
     */
    @ApiOperation(value = "新增厨房废弃物处置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:deal:add")
    @SysLog(title = "厨房废弃物处置", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增厨房废弃物处置")
    @PostMapping
    public AjaxResult add(@RequestBody KitchenWasteDeal kitchenWasteDeal) {
        try {
            return toAjax(kitchenWasteDealService.insertKitchenWasteDeal(kitchenWasteDeal));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改厨房废弃物处置
     */
    @ApiOperation(value = "修改厨房废弃物处置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:deal:edit")
    @SysLog(title = "厨房废弃物处置", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改厨房废弃物处置")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody KitchenWasteDeal kitchenWasteDeal) {
        try {
            return toAjax(kitchenWasteDealService.updateKitchenWasteDeal(kitchenWasteDeal));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除厨房废弃物处置
     */
    @ApiOperation(value = "删除厨房废弃物处置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:deal:remove")
    @SysLog(title = "厨房废弃物处置", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除厨房废弃物处置")
	@PostMapping("/del/{wasteIds}")
    public AjaxResult remove(@PathVariable Long[] wasteIds) {
        return toAjax(kitchenWasteDealService.deleteKitchenWasteDealByWasteIds(wasteIds));
    }
}
